@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.11;
+our $VERSION = 0.12;
 
 # Get XML.
 has xml => (
@@ -195,6 +195,29 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
 
 =end html
 
+=head1 EXAMPLE4
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Map::Tube::Prague;
+
+ # Object.
+ my $obj = Map::Tube::Prague->new;
+
+ # Get lines.
+ my $lines_ar = $obj->get_lines;
+
+ # Print out.
+ map { print $_->name."\n"; } sort @{$lines_ar};
+
+ # Output:
+ # Linka A
+ # Linka B
+ # Linka C
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -238,6 +261,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.11
+0.12
 
 =cut
